Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5665)

Unified Diff: chrome/browser/signin/signin_manager.h

Issue 9959038: Removed ProfileSyncService::UIShouldDepictAuthInProgress (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Merged with ToT. Created 8 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/sync/profile_sync_service.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/signin/signin_manager.h
diff --git a/chrome/browser/signin/signin_manager.h b/chrome/browser/signin/signin_manager.h
index 3fc50c84dd36a4c8c80d395cd9fffaf493cced1b..0ef4f1a09d676885f2fc349e19825c28e49be15d 100644
--- a/chrome/browser/signin/signin_manager.h
+++ b/chrome/browser/signin/signin_manager.h
@@ -98,8 +98,9 @@ class SigninManager : public GaiaAuthConsumer,
// associated with the user, and canceling all auth in progress.
virtual void SignOut();
- // Returns true if there's a signin in progress.
- bool AuthInProgress() const;
+ // Returns true if there's a signin in progress. Virtual so it can be
+ // overridden by mocks.
+ virtual bool AuthInProgress() const;
// Handles errors if a required user info key is not returned from the
// GetUserInfo call.
« no previous file with comments | « no previous file | chrome/browser/sync/profile_sync_service.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698